==> treuchtlingen-foxde-config_1.0.40.orig.tar.gz: treuchtlingen-foxde-config-1.0.40/kde-configuration/x2go/kactivitymanagerd.sql <==
PRAGMA foreign_keys=OFF;
BEGIN TRANSACTION;
CREATE TABLE SchemaInfo (key text PRIMARY KEY, value text);
INSERT INTO SchemaInfo VALUES('version','2015.02.09');
CREATE TABLE ResourceEvent (usedActivity TEXT, initiatingAgent TEXT, targettedResource TEXT, start INTEGER, end INTEGER );
CREATE TABLE ResourceScoreCache (usedActivity TEXT, initiatingAgent TEXT, targettedResource TEXT, scoreType INTEGER, cachedScore FLOAT, firstUpdate INTEGER, lastUpdate INTEGER, PRIMARY KEY(usedActivity, initiatingAgent, targettedResource));
CREATE TABLE ResourceLink (usedActivity TEXT, initiatingAgent TEXT, targettedResource TEXT, PRIMARY KEY(usedActivity, initiatingAgent, targettedResource));
INSERT INTO ResourceLink VALUES(':global','org.kde.plasma.favorites.applications','applications:firefox-esr.desktop');
INSERT INTO ResourceLink VALUES(':global','org.kde.plasma.favorites.applications','applications:thunderbird.desktop');
INSERT INTO ResourceLink VALUES(':global','org.kde.plasma.favorites.applications','applications:treuchtlingen-logout.desktop');
INSERT INTO ResourceLink VALUES(':global','org.kde.plasma.favorites.applications','applications:treuchtlingen-suspend.desktop');
INSERT INTO ResourceLink VALUES(':global','org.kde.plasma.favorites.applications','applications:libreoffice-writer.desktop');
INSERT INTO ResourceLink VALUES(':global','org.kde.plasma.favorites.applications','applications:libreoffice-calc.desktop');
INSERT INTO ResourceLink VALUES(':global','org.kde.plasma.favorites.applications','applications:org.kde.dolphin.desktop');
CREATE TABLE ResourceInfo (targettedResource TEXT, title TEXT, mimetype TEXT, autoTitle INTEGER, autoMimetype INTEGER, PRIMARY KEY(targettedResource));
COMMIT;

==> treuchtlingen-foxde-config_1.0.57.orig.tar.gz: treuchtlingen-foxde-config-1.0.57/kde-configuration/x2go/kactivitymanagerd.sql <==
PRAGMA foreign_keys=OFF;
BEGIN TRANSACTION;
CREATE TABLE SchemaInfo (key text PRIMARY KEY, value text);
INSERT INTO SchemaInfo VALUES('version','2015.02.09');
CREATE TABLE ResourceEvent (usedActivity TEXT, initiatingAgent TEXT, targettedResource TEXT, start INTEGER, end INTEGER );
CREATE TABLE ResourceScoreCache (usedActivity TEXT, initiatingAgent TEXT, targettedResource TEXT, scoreType INTEGER, cachedScore FLOAT, firstUpdate INTEGER, lastUpdate INTEGER, PRIMARY KEY(usedActivity, initiatingAgent, targettedResource));
CREATE TABLE ResourceLink (usedActivity TEXT, initiatingAgent TEXT, targettedResource TEXT, PRIMARY KEY(usedActivity, initiatingAgent, targettedResource));
INSERT INTO ResourceLink VALUES(':global','org.kde.plasma.favorites.applications','applications:firefox-esr.desktop');
INSERT INTO ResourceLink VALUES(':global','org.kde.plasma.favorites.applications','applications:thunderbird.desktop');
INSERT INTO ResourceLink VALUES(':global','org.kde.plasma.favorites.applications','applications:libreoffice-writer.desktop');
INSERT INTO ResourceLink VALUES(':global','org.kde.plasma.favorites.applications','applications:libreoffice-calc.desktop');
INSERT INTO ResourceLink VALUES(':global','org.kde.plasma.favorites.applications','applications:org.kde.dolphin.desktop');
INSERT INTO ResourceLink VALUES(':global','org.kde.plasma.favorites.applications','applications:foxde-exit-logout.desktop');
INSERT INTO ResourceLink VALUES(':global','org.kde.plasma.favorites.applications','applications:foxde-exit-suspend.desktop');
CREATE TABLE ResourceInfo (targettedResource TEXT, title TEXT, mimetype TEXT, autoTitle INTEGER, autoMimetype INTEGER, PRIMARY KEY(targettedResource));
COMMIT;
